Literature
==========

Below is a list of references that are cited in the ``embeam`` documentation:

.. [DaCosta1] |nbspc|"Prismatic 2.0 -- Simulation software for scanning and 
	             high resolution transmission electron microscopy (STEM "
		     and HRTEM)", L. Rangel DaCosta *et al*., Micron **151**,
		     103141 (2021), :doi:`10.1016/j.micron.2021.103141`

.. [Ishitani1] |nbspc|"New concept of information resolution in scanning
	              electron microscope images", T. Ishitani and M. Sato,
	              Ultramicroscopy **84**, 199-211 (2000),
	              :doi:`10.1016/S0304-3991(00)00033-4`

.. [Kirkland1] |nbspc|"Advanced Computing in Electron Microscopy", E. Kirkland,
	              Springer (2010)

.. |nbspc| unicode:: U+00A0 .. non-breaking space
